bmedian_rs: Realised beta-median score

View source: R/bmedian_rs.R

bmedian_rsR Documentation

Realised \beta-median score

Description

The function bmedian_rs computes the realised \beta-median score with parameter b, when \textbf{\textit{y}} materialises and \textbf{\textit{x}} is the prediction.

Realised \beta-median score is a realised score corresponding to the \beta-median scoring function bmedian_sf.

Usage

bmedian_rs(x, y, b)

Arguments

x

Prediction. It can be a vector of length n (must have the same length as \textbf{\textit{y}}).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as \textbf{\textit{x}}).

b

It can be a scalar.

Details

The realised \beta-median score is defined by:

S(\textbf{\textit{x}}, \textbf{\textit{y}}, b) := (1/n) \sum_{i = 1}^{n} L(x_i, y_i, b)

where

\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}

\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}

and

L(x, y, b) := |1 - (y/x)^b|

Domain of function:

\textbf{\textit{x}} > \textbf{0}

\textbf{\textit{y}} > \textbf{0}

b \neq 0

where

\textbf{0} = (0, ..., 0)^\mathsf{T}

is the zero vector of length n and the symbol > indicates pairwise inequality.

Range of function:

S(\textbf{\textit{x}}, \textbf{\textit{y}}, b) \geq 0, \forall \textbf{\textit{x}}, \textbf{\textit{y}} > \textbf{0}, b \neq 0

Value

Value of the realised \beta-median score.

Note

For details on the \beta-median scoring function, see bmedian_sf.

The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).

The realised \beta-median score is the realised (average) score corresponding to the \beta-median scoring function.

References

Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.

Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.

See Also

bmedian_sf

Examples

# Compute the realised beta-median score.

set.seed(12345)

b <- 2

x <- 0.5

y <- rlnorm(n = 100, meanlog = 0, sdlog = 1)

print(bmedian_rs(x = x, y = y, b = b))

print(bmedian_rs(x = rep(x = x, times = 100), y = y, b = b))

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.