| gpl1_rs | R Documentation |
The function gpl1_rs computes the realised generalized piecewise linear power
score (type 1) at a specific level p and parameter b, when
\textbf{\textit{y}} materialises and \textbf{\textit{x}} is the
prediction.
Realised generalized piecewise linear power score (type 1) is a realised score corresponding to the generalized piecewise linear power scoring function (type 1) gpl1_sf.
gpl1_rs(x, y, p, b)
x |
Prediction. It can be a vector of length |
y |
Realisation (true value) of process. It can be a vector of length
|
p |
It can be a scalar. |
b |
It can be a scalar. |
The realised generalized piecewise linear power score (type 1) is defined by:
S(\textbf{\textit{x}}, \textbf{\textit{y}}, p, b) := (1/n)
\sum_{i = 1}^{n} L(x_i, y_i, p, b)
where
\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}
\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}
and
L(x, y, p, b) :=
(1/b) (\textbf{1} \lbrace x \geq y \rbrace - p) (x^b - y^b)
Domain of function:
\textbf{\textit{x}} > \textbf{0}
\textbf{\textit{y}} > \textbf{0}
0 < p < 1
b > 0
where
\textbf{0} = (0, ..., 0)^\mathsf{T}
is the zero vector of length n and the symbol > indicates pairwise
inequality.
Range of function:
S(\textbf{\textit{x}}, \textbf{\textit{y}}, p, b) \geq 0,
\forall \textbf{\textit{x}}, \textbf{\textit{y}} > \textbf{0}, p \in (0, 1),
b > 0
Value of the realised generalized piecewise linear power score (type 1).
For details on the generalized piecewise linear power scoring function (type 1), see gpl1_sf.
The parameter is restricted to b > 0, where |b| = b, because
g(x) = x^b/|b| is strictly increasing only for b > 0, as required by
Theorem 9(b) in Gneiting (2011). See gpl1_sf.
The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).
The realised generalized piecewise linear power score (type 1) is the realised (average) score corresponding to the generalized piecewise linear power scoring function (type 1).
Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.
Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.
gpl1_sf, quantile_if
# Compute the realised generalized piecewise linear power score (type 1).
set.seed(12345)
p <- 0.7
b <- 2
x <- qlnorm(p = p, meanlog = 0, sdlog = 1)
y <- rlnorm(n = 100, meanlog = 0, sdlog = 1)
print(gpl1_rs(x = x, y = y, p = p, b = b))
print(gpl1_rs(x = rep(x = x, times = 100), y = y, p = p, b = b))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.