lqmean_rs: Realised L_q-mean score

View source: R/lqmean_rs.R

lqmean_rsR Documentation

Realised L_q-mean score

Description

The function lqmean_rs computes the realised L_q-mean score with parameter q, when \textbf{\textit{y}} materialises and \textbf{\textit{x}} is the prediction.

Realised L_q-mean score is a realised score corresponding to the L_q-mean scoring function lqmean_sf.

Usage

lqmean_rs(x, y, q)

Arguments

x

Prediction. It can be a vector of length n (must have the same length as \textbf{\textit{y}}).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as \textbf{\textit{x}}).

q

It can be a scalar.

Details

The realised L_q-mean score is defined by:

S(\textbf{\textit{x}}, \textbf{\textit{y}}, q) := (1/n) \sum_{i = 1}^{n} L(x_i, y_i, q)

where

\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}

\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}

and

L(x, y, q) := |x - y|^q

Domain of function:

\textbf{\textit{x}} \in \mathbb{R}^n

\textbf{\textit{y}} \in \mathbb{R}^n

q > 1

Range of function:

S(\textbf{\textit{x}}, \textbf{\textit{y}}, q) \geq 0, \forall \textbf{\textit{x}}, \textbf{\textit{y}} \in \mathbb{R}^n, q > 1

Value

Value of the realised L_q-mean score.

Note

For details on the L_q-mean scoring function, see lqmean_sf.

The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).

The realised L_q-mean score is the realised (average) score corresponding to the L_q-mean scoring function.

References

Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.

Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.

See Also

lqmean_sf

Examples

# Compute the realised Lq-mean score.

set.seed(12345)

q <- 2

x <- 0

y <- rnorm(n = 100, mean = 0, sd = 1)

print(lqmean_rs(x = x, y = y, q = q))

print(lqmean_rs(x = rep(x = x, times = 100), y = y, q = q))

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.