maelog_rs: Realised MAE-LOG score

View source: R/maelog_rs.R

maelog_rsR Documentation

Realised MAE-LOG score

Description

The function maelog_rs computes the realised MAE-LOG score when \textbf{\textit{y}} materialises and \textbf{\textit{x}} is the prediction.

Realised MAE-LOG score is a realised score corresponding to the MAE-LOG scoring function maelog_sf.

Usage

maelog_rs(x, y)

Arguments

x

Prediction. It can be a vector of length n (must have the same length as \textbf{\textit{y}}).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as \textbf{\textit{x}}).

Details

The realised MAE-LOG score is defined by:

S(\textbf{\textit{x}}, \textbf{\textit{y}}) := (1/n) \sum_{i = 1}^{n} L(x_i, y_i)

where

\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}

\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}

and

L(x, y) := |\log(x/y)|

Domain of function:

\textbf{\textit{x}} > \textbf{0}

\textbf{\textit{y}} > \textbf{0}

where

\textbf{0} = (0, ..., 0)^\mathsf{T}

is the zero vector of length n and the symbol > indicates pairwise inequality.

Range of function:

S(\textbf{\textit{x}}, \textbf{\textit{y}}) \geq 0, \forall \textbf{\textit{x}}, \textbf{\textit{y}} > \textbf{0}

Value

Value of the realised MAE-LOG score.

Note

For details on the MAE-LOG scoring function, see maelog_sf.

The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).

The realised MAE-LOG score is the realised (average) score corresponding to the MAE-LOG scoring function.

References

Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.

Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.

See Also

maelog_sf, quantile_if

Examples

# Compute the realised MAE-LOG score.

set.seed(12345)

x <- 0.5

y <- rlnorm(n = 100, meanlog = 0, sdlog = 1)

print(maelog_rs(x = x, y = y))

print(maelog_rs(x = rep(x = x, times = 100), y = y))

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.