meanexp_if: Exp-transformed identification function

View source: R/meanexp_if.R

meanexp_ifR Documentation

Exp-transformed identification function

Description

The function meanexp_if computes the exp-transformed identification function with parameter a, when y materialises and (1/a) \log(\textnormal{E}_F[\exp(aY)]) is the predictive functional.

The exp-transformed identification function is defined by Remark 1 in Tyralis and Papacharalampous (2026), applied to g(t) = \exp(at).

Usage

meanexp_if(x, y, a)

Arguments

x

Predictive (1/a) \log(\textnormal{E}_F[\exp(aY)]) functional. It can be a vector of length n (must have the same length as y).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as x).

a

It can be a vector of length n (must have the same length as y).

Details

The exp-transformed identification function is defined by:

V(x, y, a) := \exp(a x) - \exp(a y)

Domain of function:

x \in \mathbb{R}

y \in \mathbb{R}

a \neq 0

Range of function:

V(x, y, a) \in \mathbb{R}

Value

Vector of values of the exp-transformed identification function.

Note

For details on the entropic risk measure functional (1/a) \log(\textnormal{E}_F[\exp(aY)]), see Gerber (1974) and serrexp_sf.

The exp-transformed identification function is a strict \mathbb{F}-identification function for the entropic risk measure functional (1/a) \log(\textnormal{E}_F[\exp(aY)]) (Tyralis and Papacharalampous 2026).

\mathbb{F} is the family of probability distributions F for which \textnormal{E}_F[\exp(aY)] exists and is finite (Tyralis and Papacharalampous 2026).

linex_sf parameterises the same one-parameter family of entropic risk measures at the opposite sign: it elicits its functional as -(1/a) \log(\textnormal{E}_F[\exp(-aY)]), which equals the functional documented here evaluated at -a.

References

Gerber HU (1974) On additive premium calculation principles. ASTIN Bulletin: The Journal of the IAA 7(3):215–222. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/S0515036100006061")}.

Tyralis H, Papacharalampous G (2026) Variable transformations in consistent loss functions. Knowledge-Based Systems 336:115202. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.knosys.2025.115202")}.

See Also

serrexp_sf, serrexp_rs

Examples

# Compute the exp-transformed identification function.

df <- data.frame(
    y = rep(x = 2, times = 3),
    x = 1:3,
    a = c(-1, 1, 2)
)

df$meanexp_if <- meanexp_if(x = df$x, y = df$y, a = df$a)

print(df)

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.