meanpower_if: Power-transformed identification function

View source: R/meanpower_if.R

meanpower_ifR Documentation

Power-transformed identification function

Description

The function meanpower_if computes the power-transformed identification function with parameter a, when y materialises and (\textnormal{E}_F[Y^a])^{(1/a)} is the predictive functional.

The power-transformed identification function is defined by Remark 1 in Tyralis and Papacharalampous (2026), applied to g(t) = t^a.

Usage

meanpower_if(x, y, a)

Arguments

x

Predictive (\textnormal{E}_F[Y^a])^{(1/a)} functional. It can be a vector of length n (must have the same length as y).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as x).

a

It can be a vector of length n (must have the same length as y).

Details

The power-transformed identification function is defined by:

V(x, y, a) := x^a - y^a

Domain of function:

Case #1

a > 0

x \geq 0

y \geq 0

Case #2

a \neq 0

x > 0

y > 0

Range of function:

V(x, y, a) \in \mathbb{R}

Value

Vector of values of the power-transformed identification function.

Note

For details on the (\textnormal{E}_F[Y^a])^{(1/a)} functional, see serrpower_sf.

The power-transformed identification function is a strict \mathbb{F}-identification function for the (\textnormal{E}_F[Y^a])^{(1/a)} functional (Tyralis and Papacharalampous 2026).

\mathbb{F} is the family of probability distributions F for which \textnormal{E}_F[Y^a] exists and is finite (Tyralis and Papacharalampous 2026).

At a = 2, this is the identification function counterpart of serrsq_sf, which has no dedicated identification function of its own in this package.

References

Tyralis H, Papacharalampous G (2026) Variable transformations in consistent loss functions. Knowledge-Based Systems 336:115202. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.knosys.2025.115202")}.

See Also

serrpower_sf, serrpower_rs

Examples

# Compute the power-transformed identification function.

df <- data.frame(
    y = rep(x = 2, times = 3),
    x = 1:3,
    a = c(1, 2, 3)
)

df$meanpower_if <- meanpower_if(x = df$x, y = df$y, a = df$a)

print(df)

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.