mv_sf: Mean - variance scoring function

View source: R/mv_sf.R

mv_sfR Documentation

Mean - variance scoring function

Description

The function mv_sf computes the mean - variance scoring function, when y materialises, x_1 is the predictive mean and x_2 is the predictive variance.

The mean - variance scoring function is defined by eq. (3.11) in Fissler and Ziegel (2019).

Usage

mv_sf(x1, x2, y)

Arguments

x1

Predictive mean (prediction). It can be a vector of length n (must have the same length as y).

x2

Predictive variance (prediction). It can be a vector of length n (must have the same length as y).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as x_1 and x_2).

Details

The mean - variance scoring function is defined by:

S(x_1, x_2, y) := x_2^{-2} (x_1^2 - 2 x_2 - 2 x_1 y + y^2)

Domain of function:

x_1 \in \mathbb{R}

x_2 > 0

y \in \mathbb{R}

Range of function:

S(x_1, x_2, y) \geq -2/x_2, \forall x_1, y \in \mathbb{R}, x_2 > 0

Value

Vector of mean - variance losses.

Note

The mean functional is the mean \textnormal{E}_F[Y] of the probability distribution F of Y (Gneiting 2011).

The variance functional is the variance \textnormal{Var}_F[Y] := \textnormal{E}_F[Y^2] - (\textnormal{E}_F[Y])^{2} of the probability distribution F of Y (Gneiting 2011).

The mean - variance scoring function is negatively oriented (i.e. the smaller, the better).

The mean - variance scoring function is strictly \mathbb{F}-consistent for the pair (mean, variance) functional (eq. (3.11) and Example 3.19 in Fissler and Ziegel (2019); Proposition 4.4 in Fissler and Ziegel (2016)). \mathbb{F} is the family of probability distributions F for which \textnormal{E}_F[Y] and \textnormal{E}_F[Y^2] exist and are finite (eq. (3.11) and Example 3.19 in Fissler and Ziegel (2019); Proposition 4.4 in Fissler and Ziegel (2016)).

References

Fissler T, Ziegel JF (2016) Higher order elicitability and Osband's principle. The Annals of Statistics 44(4):1680–1707. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/16-AOS1439")}.

Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.

See Also

mv_if

Examples

# Compute the mean - variance scoring function.

df <- data.frame(
    y = rep(x = 0, times = 6),
    x1 = c(2, 2, -2, -2, 0, 0),
    x2 = c(1, 2, 1, 2, 1, 2)
)

df$mv_penalty <- mv_sf(x1 = df$x1, x2 = df$x2, y = df$y)

print(df)

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.