serrexp_rs: Realised squared error exp score

View source: R/serrexp_rs.R

serrexp_rsR Documentation

Realised squared error exp score

Description

The function serrexp_rs computes the realised squared error exp score with parameter a, when \textbf{\textit{y}} materialises and \textbf{\textit{x}} is the prediction.

Realised squared error exp score is a realised score corresponding to the squared error exp scoring function serrexp_sf.

Usage

serrexp_rs(x, y, a)

Arguments

x

Prediction. It can be a vector of length n (must have the same length as \textbf{\textit{y}}).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as \textbf{\textit{x}}).

a

It can be a scalar.

Details

The realised squared error exp score is defined by:

S(\textbf{\textit{x}}, \textbf{\textit{y}}, a) := (1/n) \sum_{i = 1}^{n} L(x_i, y_i, a)

where

\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}

\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}

and

L(x, y, a) := (\textnormal{e}^{a x} - \textnormal{e}^{a y})^2

Domain of function:

\textbf{\textit{x}} \in \mathbb{R}^n

\textbf{\textit{y}} \in \mathbb{R}^n

a \neq 0

Range of function:

S(\textbf{\textit{x}}, \textbf{\textit{y}}, a) \geq 0, \forall \textbf{\textit{x}}, \textbf{\textit{y}} \in \mathbb{R}^n, a \neq 0

Value

Value of the realised squared error exp score.

Note

For details on the squared error exp scoring function, see serrexp_sf.

The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).

The realised squared error exp score is the realised (average) score corresponding to the squared error exp scoring function.

References

Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.

Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.

See Also

serrexp_sf, meanexp_if

Examples

# Compute the realised squared error exp score.

set.seed(12345)

a <- 1

x <- 0

y <- rnorm(n = 100, mean = 0, sd = 1)

print(serrexp_rs(x = x, y = y, a = a))

print(serrexp_rs(x = rep(x = x, times = 100), y = y, a = a))

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.