| serrpower_sf | R Documentation |
The function serrpower_sf computes the squared error of power transformations
scoring function when y materialises and x is the
(\textnormal{E}_F[Y^a])^{(1/a)} predictive functional.
The squared error of power transformations scoring function is defined in Tyralis and Papacharalampous (2026).
serrpower_sf(x, y, a)
x |
Predictive |
y |
Realisation (true value) of process. It can be a vector of length
|
a |
It can be a vector of length |
The squared error of power transformations scoring function is defined by:
S(x, y, a) := (x^a - y^a)^2
Domain of function:
Case #1
a > 0
x \geq 0
y \geq 0
Case #2
a \neq 0
x > 0
y > 0
Range of function:
Case #1
S(x, y, a) \geq 0, \forall x, y \geq 0, a > 0
Case #2
S(x, y, a) \geq 0, \forall x, y > 0, a \neq 0
Vector of squared errors of power-transformed variables.
For details on the squared error of power transformations scoring function, see Tyralis and Papacharalampous (2026).
The squared error of power transformations scoring function is negatively oriented (i.e. the smaller, the better).
The squared error of power transformations scoring function is strictly
\mathbb{F}-consistent for the (\textnormal{E}_F[Y^a])^{(1/a)}
functional. \mathbb{F} is the family of probability distributions F
for which \textnormal{E}_F[Y^{2 a}] exists and is finite (Tyralis and
Papacharalampous 2026).
Tyralis H, Papacharalampous G (2026) Variable transformations in consistent loss functions. Knowledge-Based Systems 336:115202. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.knosys.2025.115202")}.
serrpower_rs, meanpower_if
# Compute the squared error of power transformations scoring function.
df <- data.frame(
y = rep(x = 2, times = 3),
x = 1:3,
a = 1:3
)
df$squaredpower_error <- serrpower_sf(x = df$x, y = df$y, a = df$a)
print(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.