serrsq_rs: Realised squared error of squares score

View source: R/serrsq_rs.R

serrsq_rsR Documentation

Realised squared error of squares score

Description

The function serrsq_rs computes the realised squared error of squares score when \textbf{\textit{y}} materialises and \textbf{\textit{x}} is the prediction.

Realised squared error of squares score is a realised score corresponding to the squared error of squares scoring function serrsq_sf.

Usage

serrsq_rs(x, y)

Arguments

x

Prediction. It can be a vector of length n (must have the same length as \textbf{\textit{y}}).

y

Realisation (true value) of process. It can be a vector of length n (must have the same length as \textbf{\textit{x}}).

Details

The realised squared error of squares score is defined by:

S(\textbf{\textit{x}}, \textbf{\textit{y}}) := (1/n) \sum_{i = 1}^{n} L(x_i, y_i)

where

\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}

\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}

and

L(x, y) := (x^2 - y^2)^2

Domain of function:

\textbf{\textit{x}} \geq \textbf{0}

\textbf{\textit{y}} \geq \textbf{0}

where

\textbf{0} = (0, ..., 0)^\mathsf{T}

is the zero vector of length n and the symbol \geq indicates pairwise inequality.

Range of function:

S(\textbf{\textit{x}}, \textbf{\textit{y}}) \geq 0, \forall \textbf{\textit{x}}, \textbf{\textit{y}} \geq \textbf{0}

Value

Value of the realised squared error of squares score.

Note

For details on the squared error of squares scoring function, see serrsq_sf.

The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).

The realised squared error of squares score is the realised (average) score corresponding to the squared error of squares scoring function.

References

Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.

Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.

See Also

serrsq_sf

Examples

# Compute the realised squared error of squares score.

set.seed(12345)

x <- 0.5

y <- rlnorm(n = 100, meanlog = 0, sdlog = 1)

print(serrsq_rs(x = x, y = y))

print(serrsq_rs(x = rep(x = x, times = 100), y = y))

scoringfunctions documentation built on Aug. 30, 2026, 5:07 p.m.