| gpl2_rs | R Documentation |
The function gpl2_rs computes the realised generalized piecewise linear power
score (type 2) at a specific level p, when \textbf{\textit{y}}
materialises and \textbf{\textit{x}} is the prediction.
Realised generalized piecewise linear power score (type 2) is a realised score corresponding to the generalized piecewise linear power scoring function (type 2) gpl2_sf.
gpl2_rs(x, y, p)
x |
Prediction. It can be a vector of length |
y |
Realisation (true value) of process. It can be a vector of length
|
p |
It can be a scalar. |
The realised generalized piecewise linear power score (type 2) is defined by:
S(\textbf{\textit{x}}, \textbf{\textit{y}}, p) := (1/n)
\sum_{i = 1}^{n} L(x_i, y_i, p)
where
\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}
\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}
and
L(x, y, p) := (\textbf{1} \lbrace x \geq y \rbrace - p) \log(x/y)
Domain of function:
\textbf{\textit{x}} > \textbf{0}
\textbf{\textit{y}} > \textbf{0}
0 < p < 1
where
\textbf{0} = (0, ..., 0)^\mathsf{T}
is the zero vector of length n and the symbol > indicates pairwise
inequality.
Range of function:
S(\textbf{\textit{x}}, \textbf{\textit{y}}, p) \geq 0,
\forall \textbf{\textit{x}}, \textbf{\textit{y}} > \textbf{0}, p \in (0, 1)
Value of the realised generalized piecewise linear power score (type 2).
For details on the generalized piecewise linear power scoring function (type 2), see gpl2_sf.
The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).
The realised generalized piecewise linear power score (type 2) is the realised (average) score corresponding to the generalized piecewise linear power scoring function (type 2).
Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.
Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.
gpl2_sf, quantile_if
# Compute the realised generalized piecewise linear power score (type 2).
set.seed(12345)
p <- 0.7
x <- qlnorm(p = p, meanlog = 0, sdlog = 1)
y <- rlnorm(n = 100, meanlog = 0, sdlog = 1)
print(gpl2_rs(x = x, y = y, p = p))
print(gpl2_rs(x = rep(x = x, times = 100), y = y, p = p))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.