| meanlog_if | R Documentation |
The function meanlog_if computes the log-transformed identification function,
when y materialises and \exp(\textnormal{E}_F[\log(Y)]), the
geometric mean of F (Yeh et al. 2008), is the predictive functional.
The log-transformed identification function is defined in Tyralis and Papacharalampous (2026).
meanlog_if(x, y)
x |
Predictive |
y |
Realisation (true value) of process. It can be a vector of length
|
The log-transformed identification function is defined by:
V(x, y) := \log(x) - \log(y)
Domain of function:
x > 0
y > 0
Range of function:
V(x, y) \in \mathbb{R}, \forall x, y > 0
Vector of values of the log-transformed identification function.
The \exp(\textnormal{E}_F[\log(Y)]) functional is the geometric mean of
the probability distribution F of Y, i.e. the r = 0 case of
the generalized (power) mean of order r defined by eq. (2.1) in Yeh et
al. (2008).
The log-transformed identification function is a strict
\mathbb{F}-identification function for the log-transformed expectation
\exp(\textnormal{E}_F[\log(Y)]) (Tyralis and Papacharalampous 2026).
\mathbb{F} is the family of probability distributions F for which
\textnormal{E}_F[\log(Y)] exists and is finite (Tyralis and
Papacharalampous 2026).
Tyralis H, Papacharalampous G (2026) Variable transformations in consistent loss functions. Knowledge-Based Systems 336:115202. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.knosys.2025.115202")}.
Yeh C-C, Yeh H-W, Chan W (2008) Some equivalent forms of the arithematic-geometric mean inequality in probability: A survey. Journal of Inequalities and Applications 2008:386715. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1155/2008/386715")}.
serrlog_sf, serrlog_rs
# Compute the log-transformed identification function.
df <- data.frame(
y = rep(x = 2, times = 3),
x = 1:3
)
df$meanlog_if <- meanlog_if(x = df$x, y = df$y)
print(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.