| qlike | R Documentation |
The function qlike computes the QLIKE score when \textbf{\textit{y}}
materialises and \textbf{\textit{x}} is the prediction.
QLIKE is a realised score corresponding to the Bregman scoring function (type 3, QLIKE scoring function) bregman3_sf.
qlike(x, y)
x |
Prediction. It can be a vector of length |
y |
Realisation (true value) of process. It can be a vector of length
|
QLIKE is defined by:
S(\textbf{\textit{x}}, \textbf{\textit{y}}) := (1/n)
\sum_{i = 1}^{n} L(x_i, y_i)
where
\textbf{\textit{x}} = (x_1, ..., x_n)^\mathsf{T}
\textbf{\textit{y}} = (y_1, ..., y_n)^\mathsf{T}
and
L(x, y) := (y/x) - \log(y/x) - 1
Domain of function:
\textbf{\textit{x}} > \textbf{0}
\textbf{\textit{y}} > \textbf{0}
where
\textbf{0} = (0, ..., 0)^\mathsf{T}
is the zero vector of length n and the symbol > indicates pairwise
inequality.
Range of function:
S(\textbf{\textit{x}}, \textbf{\textit{y}}) \geq 0,
\forall \textbf{\textit{x}}, \textbf{\textit{y}} > \textbf{0}
Value of QLIKE.
For details on the Bregman scoring function (type 3, QLIKE scoring function), see bregman3_sf.
The concept of realised (average) scores is defined by Gneiting (2011) and Fissler and Ziegel (2019).
QLIKE is the realised (average) score corresponding to the Bregman scoring function (type 3, QLIKE scoring function).
Fissler T, Ziegel JF (2019) Order-sensitivity and equivariance of scoring functions. Electronic Journal of Statistics 13(1):1166–1211. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-EJS1552")}.
Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.
bregman3_sf, mean_if
# Compute QLIKE.
set.seed(12345)
x <- 0.5
y <- rlnorm(n = 100, meanlog = 0, sdlog = 1)
print(qlike(x = x, y = y))
print(qlike(x = rep(x = x, times = 100), y = y))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.