| serrlog_sf | R Documentation |
The function serrlog_sf computes the squared error log scoring function when
y materialises and x is the \exp(\textnormal{E}_F[\log(Y)])
predictive functional, i.e. the geometric mean of F (Yeh et al. 2008).
The squared error log scoring function is described by eq. (2) in Houghton-Carr (1999).
serrlog_sf(x, y)
x |
Predictive |
y |
Realisation (true value) of process. It can be a vector of length
|
The squared error log scoring function is defined by:
S(x, y) := (\log(x) - \log(y))^2
Domain of function:
x > 0
y > 0
Range of function:
S(x, y) \geq 0, \forall x, y > 0
Vector of squared errors of log-transformed variables.
For details on the squared error log scoring function, see Houghton-Carr (1999).
The \exp(\textnormal{E}_F[\log(Y)]) functional is the geometric mean of
the probability distribution F of Y, i.e. the r = 0 case of
the generalized (power) mean of order r defined by eq. (2.1) in Yeh et
al. (2008).
The squared error log scoring function is negatively oriented (i.e. the smaller, the better).
The squared error log scoring function is strictly \mathbb{F}-consistent
for the \exp(\textnormal{E}_F[\log(Y)]) functional. \mathbb{F} is
the family of probability distributions F for which
\textnormal{E}_F[(\log(Y))^2] exists and is finite (Tyralis and
Papacharalampous 2026).
Houghton-Carr HA (1999) Assessment criteria for simple conceptual daily rainfall-runoff models. Hydrological Sciences Journal 44(2):237–261. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/02626669909492220")}.
Tyralis H, Papacharalampous G (2026) Variable transformations in consistent loss functions. Knowledge-Based Systems 336:115202. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.knosys.2025.115202")}.
Yeh C-C, Yeh H-W, Chan W (2008) Some equivalent forms of the arithematic-geometric mean inequality in probability: A survey. Journal of Inequalities and Applications 2008:386715. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1155/2008/386715")}.
serrlog_rs, meanlog_if
# Compute the squared error log scoring function.
df <- data.frame(
y = rep(x = 2, times = 3),
x = 1:3
)
df$squaredlog_error <- serrlog_sf(x = df$x, y = df$y)
print(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.