| srelerr_sf | R Documentation |
The function srelerr_sf computes the squared relative error scoring function
when y materialises and x is the predictive
\dfrac{\textnormal{E}_F [Y^{2}]}{\textnormal{E}_F [Y]} functional.
The squared relative error scoring function is defined on p. 752 in Gneiting (2011).
srelerr_sf(x, y)
x |
Predictive |
y |
Realisation (true value) of process. It can be a vector of length
|
The squared relative error scoring function is defined by:
S(x, y) := ((x - y)/x)^{2}
Domain of function:
x > 0
y > 0
Range of function:
S(x, y) \geq 0, \forall x, y > 0
Vector of squared relative errors.
For details on the squared relative error scoring function, see Gneiting (2011).
The squared relative error scoring function is negatively oriented (i.e. the smaller, the better).
The squared relative error scoring function is strictly
\mathbb{F}-consistent for the
\dfrac{\textnormal{E}_F [Y^{2}]}{\textnormal{E}_F [Y]} functional
(eq. (12) on p. 752 in Gneiting 2011). \mathbb{F} is the family of
probability distributions F concentrated on (0, \infty) for which
\textnormal{E}_F[Y^{2}] exists and is finite (Gneiting 2011).
The squared relative error scoring function weights with the prediction x
rather than with the realisation y, so it is not a member of the weighted
family of Theorem 5 in Gneiting (2011); it targets the same functional as
obsweighted_sf, which is
\dfrac{\textnormal{E}_F [Y^{2}]}{\textnormal{E}_F [Y]}
(eq. (12) on p. 752 in Gneiting 2011).
Gneiting T (2011) Making and evaluating point forecasts. Journal of the American Statistical Association 106(494):746–762. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jasa.2011.r10138")}.
msre
# Compute the squared relative error scoring function.
df <- data.frame(
y = rep(x = 2, times = 3),
x = 1:3
)
df$squared_relative_error <- srelerr_sf(x = df$x, y = df$y)
print(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.